@@ -1,7 +1,7 @@
 # The sampler controls the actual Gibbs sampling iteration scheme.
 # This function is called by mice and mice.mids
-sampler <- function(data, m, ignore, where, imp, blocks, method, 
-                    visitSequence, predictorMatrix, formulas, blots, 
+sampler <- function(data, m, ignore, where, imp, blocks, method,
+                    visitSequence, predictorMatrix, formulas, blots,
                     post, fromto, printFlag, ...) {
   from <- fromto[1]
   to <- fromto[2]
@@ -89,7 +89,8 @@ sampler <- function(data, m, ignore, where, imp, blocks, method,
               cmd <- post[j]
               if (cmd != "") {
                 eval(parse(text = cmd))
-                data[where[, j], j] <- imp[[j]][, i]
+                data[(!r[, j]) & where[, j], j] <-
+                  imp[[j]][(!r[, j])[where[, j]], i]
               }
             }
           }
